!-------------------------------------------------------------------------------

!VERS

! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2014 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

subroutine usphyv &
 ( nvar   , nscal  ,                                              &
   mbrom  ,                                                       &
   dt     )

!===============================================================================

!===============================================================================
! Module files
!===============================================================================

use paramx
use pointe
use numvar
use optcal
use cstphy
use entsor
use parall
use period
use field
use mesh

!===============================================================================

implicit none

! Arguments

integer          nvar   , nscal

integer          mbrom

double precision dt(ncelet)

! Local variables

integer          iel
double precision xrtp

double precision, dimension(:), pointer :: coefap, coefbp
double precision, dimension(:), pointer :: brom, crom
double precision, dimension(:), pointer :: csca

!===============================================================================

double precision pref, tref, rr, xhe, xco2
integer ifac

!===============================================================================
! 0. Initializations to keep
!===============================================================================

! --- Memory initialization



!===============================================================================

!   The following examples should be adapted by the user
!   ====================================================

!  Each example is bounded by a test on "iutile", as a precaution.
!  Set iutile to 1 to activate the example.

!  It is recommended to keep only the minimum necessary in this file
!  (i.e. remove all unused example code)

!===============================================================================



! Position of variables, coefficients
! -----------------------------------

! --- Boundary conditions

call field_get_coefa_s(ivarfl(isca(1)), coefap)
call field_get_coefb_s(ivarfl(isca(1)), coefbp)

! --- Density

call field_get_val_s(icrom, crom)
call field_get_val_s(ibrom, brom)

! --- Coefficients of laws chosen by the user

pref = 101325.d0
tref = 293.15d0
rr   = 8.31434d0
xhe  = 4.0026d-3
xco2 = 4.401d-2

print *, 'here'

! Density at cell centers
!------------------------
! law                    rho  = t  * ( a *  t +  b) +   c
! so      crom(iel) = xrtp * (vara*xrtp+varb) + varc

call field_get_val_s(ivarfl(isca(1)), csca)

do iel = 1, ncelet
  xrtp = csca(iel)
  crom(iel) = pref/((xrtp/xhe + (1.d0 - xrtp)/xco2)*(rr*tref))
enddo

do ifac = 1, nfabor
  iel  = ifabor(ifac)
  xrtp = coefap(ifac) + csca(iel)*coefbp(ifac)
  brom(ifac) = pref/((xrtp/xhe + (1.d0 - xrtp)/xco2)*(rr*tref))
enddo

mbrom = 1


!===============================================================================

!----
! Formats
!----

!----
! End
!----

return
end subroutine usphyv
